@@ -11,6 +11,9 @@ def action_caller(service):
 
 
 SERVICE_VERSIONS = {
+    "ams": [
+        "2020-12-29"
+    ],
     "antiddos": [
         "2020-03-09"
     ],
@@ -44,6 +47,9 @@ SERVICE_VERSIONS = {
     "chdfs": [
         "2020-11-12"
     ],
+    "ciam": [
+        "2021-04-20"
+    ],
     "ckafka": [
         "2019-08-19"
     ],
@@ -84,9 +90,18 @@ SERVICE_VERSIONS = {
     "dts": [
         "2018-03-30"
     ],
+    "eb": [
+        "2021-04-16"
+    ],
     "ecdn": [
         "2019-10-12"
     ],
+    "ecm": [
+        "2019-07-19"
+    ],
+    "eiam": [
+        "2021-04-20"
+    ],
     "emr": [
         "2019-01-03"
     ],
@@ -111,6 +126,9 @@ SERVICE_VERSIONS = {
     "iai": [
         "2020-03-03"
     ],
+    "ims": [
+        "2020-12-29"
+    ],
     "iotcloud": [
         "2021-04-08"
     ],
@@ -165,6 +183,9 @@ SERVICE_VERSIONS = {
     "redis": [
         "2018-04-12"
     ],
+    "rum": [
+        "2021-06-22"
+    ],
     "scf": [
         "2018-04-16"
     ],
@@ -190,12 +211,18 @@ SERVICE_VERSIONS = {
     "tag": [
         "2018-08-13"
     ],
+    "tat": [
+        "2020-10-28"
+    ],
     "tcaplusdb": [
         "2019-08-23"
     ],
     "tcr": [
         "2019-09-24"
     ],
+    "tdmq": [
+        "2020-02-17"
+    ],
     "tem": [
         "2021-07-01",
         "2020-12-21"
@@ -206,9 +233,15 @@ SERVICE_VERSIONS = {
     "tke": [
         "2018-05-25"
     ],
+    "tms": [
+        "2020-12-29"
+    ],
     "trtc": [
         "2019-07-22"
     ],
+    "vm": [
+        "2020-12-29"
+    ],
     "vod": [
         "2018-07-17"
     ],
