@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -391,33 +393,6 @@ def doDescribeJob(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeComputeEnvActivities(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.BatchClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeComputeEnvActivitiesRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.DescribeComputeEnvActivities(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
 def doTerminateComputeNodes(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -634,7 +609,7 @@ def doDescribeComputeEnvCreateInfo(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doSubmitJob(args, parsed_globals):
+def doDescribeComputeEnvActivities(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -650,9 +625,9 @@ def doSubmitJob(args, parsed_globals):
     client = mod.BatchClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.SubmitJobRequest()
+    model = models.DescribeComputeEnvActivitiesRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.SubmitJob(model)
+    rsp = client.DescribeComputeEnvActivities(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -821,7 +796,6 @@ ACTION_MAP = {
     "DescribeTask": doDescribeTask,
     "DescribeComputeEnv": doDescribeComputeEnv,
     "DescribeJob": doDescribeJob,
-    "DescribeComputeEnvActivities": doDescribeComputeEnvActivities,
     "TerminateComputeNodes": doTerminateComputeNodes,
     "DescribeTaskTemplates": doDescribeTaskTemplates,
     "DescribeInstanceCategories": doDescribeInstanceCategories,
@@ -830,7 +804,7 @@ ACTION_MAP = {
     "ModifyComputeEnv": doModifyComputeEnv,
     "DescribeJobSubmitInfo": doDescribeJobSubmitInfo,
     "DescribeComputeEnvCreateInfo": doDescribeComputeEnvCreateInfo,
-    "SubmitJob": doSubmitJob,
+    "DescribeComputeEnvActivities": doDescribeComputeEnvActivities,
     "DescribeComputeEnvCreateInfos": doDescribeComputeEnvCreateInfos,
     "DescribeJobs": doDescribeJobs,
     "DeleteComputeEnv": doDeleteComputeEnv,
@@ -914,5 +888,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
