@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -40,6 +42,33 @@ def doModifyDiskExtraPerformance(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doCopySnapshotCrossRegions(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.CbsClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.CopySnapshotCrossRegionsRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.CopySnapshotCrossRegions(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDescribeInstancesDiskNum(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -283,6 +312,33 @@ def doDeleteAutoSnapshotPolicies(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doCreateAutoSnapshotPolicy(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.CbsClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.CreateAutoSnapshotPolicyRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.CreateAutoSnapshotPolicy(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDescribeDisks(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -526,7 +582,7 @@ def doDescribeSnapshotSharePermission(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doCreateAutoSnapshotPolicy(args, parsed_globals):
+def doInitializeDisks(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -542,9 +598,9 @@ def doCreateAutoSnapshotPolicy(args, parsed_globals):
     client = mod.CbsClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.CreateAutoSnapshotPolicyRequest()
+    model = models.InitializeDisksRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.CreateAutoSnapshotPolicy(model)
+    rsp = client.InitializeDisks(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -835,6 +891,7 @@ MODELS_MAP = {
 
 ACTION_MAP = {
     "ModifyDiskExtraPerformance": doModifyDiskExtraPerformance,
+    "CopySnapshotCrossRegions": doCopySnapshotCrossRegions,
     "DescribeInstancesDiskNum": doDescribeInstancesDiskNum,
     "InquiryPriceResizeDisk": doInquiryPriceResizeDisk,
     "ApplySnapshot": doApplySnapshot,
@@ -844,6 +901,7 @@ ACTION_MAP = {
     "InquiryPriceCreateDisks": doInquiryPriceCreateDisks,
     "DescribeDiskOperationLogs": doDescribeDiskOperationLogs,
     "DeleteAutoSnapshotPolicies": doDeleteAutoSnapshotPolicies,
+    "CreateAutoSnapshotPolicy": doCreateAutoSnapshotPolicy,
     "DescribeDisks": doDescribeDisks,
     "CreateDisks": doCreateDisks,
     "ModifyDiskAttributes": doModifyDiskAttributes,
@@ -853,7 +911,7 @@ ACTION_MAP = {
     "BindAutoSnapshotPolicy": doBindAutoSnapshotPolicy,
     "DescribeSnapshots": doDescribeSnapshots,
     "DescribeSnapshotSharePermission": doDescribeSnapshotSharePermission,
-    "CreateAutoSnapshotPolicy": doCreateAutoSnapshotPolicy,
+    "InitializeDisks": doInitializeDisks,
     "TerminateDisks": doTerminateDisks,
     "DescribeDiskConfigQuota": doDescribeDiskConfigQuota,
     "UnbindAutoSnapshotPolicy": doUnbindAutoSnapshotPolicy,
@@ -942,5 +1000,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
