@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -40,6 +42,33 @@ def doRegisterTargets(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeCrossTargets(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeCrossTargetsRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeCrossTargets(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doSetLoadBalancerSecurityGroups(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -148,6 +177,33 @@ def doDescribeBlockIPTask(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doModifyTargetWeight(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.ModifyTargetWeightRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.ModifyTargetWeight(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doCreateListener(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -337,6 +393,33 @@ def doCreateRule(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeClassicalLBHealthStatus(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeClassicalLBHealthStatusRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeClassicalLBHealthStatus(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doAutoRewrite(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1012,7 +1095,7 @@ def doDescribeCustomizedConfigList(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doModifyTargetWeight(args, parsed_globals):
+def doDescribeLBListeners(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -1028,9 +1111,9 @@ def doModifyTargetWeight(args, parsed_globals):
     client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ModifyTargetWeightRequest()
+    model = models.DescribeLBListenersRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.ModifyTargetWeight(model)
+    rsp = client.DescribeLBListeners(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -1093,6 +1176,33 @@ def doDescribeTargetGroups(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeRewrite(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeRewriteRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeRewrite(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doModifyRule(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1255,6 +1365,33 @@ def doCreateTargetGroup(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeLoadBalancerOverview(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeLoadBalancerOverviewRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeLoadBalancerOverview(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDescribeTargets(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1282,7 +1419,7 @@ def doDescribeTargets(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeRewrite(args, parsed_globals):
+def doMigrateClassicalLoadBalancers(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -1298,9 +1435,9 @@ def doDescribeRewrite(args, parsed_globals):
     client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeRewriteRequest()
+    model = models.MigrateClassicalLoadBalancersRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribeRewrite(model)
+    rsp = client.MigrateClassicalLoadBalancers(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -1390,7 +1527,7 @@ def doModifyTargetGroupAttribute(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeClassicalLBHealthStatus(args, parsed_globals):
+def doModifyLoadBalancerSla(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -1406,9 +1543,9 @@ def doDescribeClassicalLBHealthStatus(args, parsed_globals):
     client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeClassicalLBHealthStatusRequest()
+    model = models.ModifyLoadBalancerSlaRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribeClassicalLBHealthStatus(model)
+    rsp = client.ModifyLoadBalancerSla(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -1552,6 +1689,33 @@ def doReplaceCertForLoadBalancers(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doCloneLoadBalancer(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.ClbClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.CloneLoadBalancerRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.CloneLoadBalancer(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doModifyTargetGroupInstancesPort(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1753,10 +1917,12 @@ MODELS_MAP = {
 
 ACTION_MAP = {
     "RegisterTargets": doRegisterTargets,
+    "DescribeCrossTargets": doDescribeCrossTargets,
     "SetLoadBalancerSecurityGroups": doSetLoadBalancerSecurityGroups,
     "DescribeClassicalLBListeners": doDescribeClassicalLBListeners,
     "DescribeCustomizedConfigAssociateList": doDescribeCustomizedConfigAssociateList,
     "DescribeBlockIPTask": doDescribeBlockIPTask,
+    "ModifyTargetWeight": doModifyTargetWeight,
     "CreateListener": doCreateListener,
     "DeleteLoadBalancerSnatIps": doDeleteLoadBalancerSnatIps,
     "DeleteListener": doDeleteListener,
@@ -1764,6 +1930,7 @@ ACTION_MAP = {
     "BatchDeregisterTargets": doBatchDeregisterTargets,
     "RegisterTargetGroupInstances": doRegisterTargetGroupInstances,
     "CreateRule": doCreateRule,
+    "DescribeClassicalLBHealthStatus": doDescribeClassicalLBHealthStatus,
     "AutoRewrite": doAutoRewrite,
     "DescribeLoadBalancerTraffic": doDescribeLoadBalancerTraffic,
     "ModifyDomain": doModifyDomain,
@@ -1789,26 +1956,29 @@ ACTION_MAP = {
     "BatchRegisterTargets": doBatchRegisterTargets,
     "DescribeClsLogSet": doDescribeClsLogSet,
     "DescribeCustomizedConfigList": doDescribeCustomizedConfigList,
-    "ModifyTargetWeight": doModifyTargetWeight,
+    "DescribeLBListeners": doDescribeLBListeners,
     "DescribeTaskStatus": doDescribeTaskStatus,
     "DescribeTargetGroups": doDescribeTargetGroups,
+    "DescribeRewrite": doDescribeRewrite,
     "ModifyRule": doModifyRule,
     "DeleteRule": doDeleteRule,
     "SetLoadBalancerClsLog": doSetLoadBalancerClsLog,
     "DescribeTargetGroupList": doDescribeTargetGroupList,
     "ModifyBlockIPList": doModifyBlockIPList,
     "CreateTargetGroup": doCreateTargetGroup,
+    "DescribeLoadBalancerOverview": doDescribeLoadBalancerOverview,
     "DescribeTargets": doDescribeTargets,
-    "DescribeRewrite": doDescribeRewrite,
+    "MigrateClassicalLoadBalancers": doMigrateClassicalLoadBalancers,
     "RegisterTargetsWithClassicalLB": doRegisterTargetsWithClassicalLB,
     "ModifyTargetPort": doModifyTargetPort,
     "ModifyTargetGroupAttribute": doModifyTargetGroupAttribute,
-    "DescribeClassicalLBHealthStatus": doDescribeClassicalLBHealthStatus,
+    "ModifyLoadBalancerSla": doModifyLoadBalancerSla,
     "DeregisterTargets": doDeregisterTargets,
     "ModifyLoadBalancerAttributes": doModifyLoadBalancerAttributes,
     "CreateClsLogSet": doCreateClsLogSet,
     "DescribeClassicalLBByInstanceId": doDescribeClassicalLBByInstanceId,
     "ReplaceCertForLoadBalancers": doReplaceCertForLoadBalancers,
+    "CloneLoadBalancer": doCloneLoadBalancer,
     "ModifyTargetGroupInstancesPort": doModifyTargetGroupInstancesPort,
     "BatchModifyTargetWeight": doBatchModifyTargetWeight,
     "DescribeQuota": doDescribeQuota,
@@ -1894,5 +2064,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
