@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -13,6 +15,33 @@ from tencentcloud.faceid.v20180301 import faceid_client as faceid_client_v201803
 from tencentcloud.faceid.v20180301 import models as models_v20180301
 
 
+def doDetectReflectLivenessAndCompare(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.FaceidClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DetectReflectLivenessAndCompareRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DetectReflectLivenessAndCompare(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doLivenessCompare(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -51,6 +80,7 @@ MODELS_MAP = {
 }
 
 ACTION_MAP = {
+    "DetectReflectLivenessAndCompare": doDetectReflectLivenessAndCompare,
     "LivenessCompare": doLivenessCompare,
 
 }
@@ -130,5 +160,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
