@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -283,7 +285,7 @@ def doModifyPersonBaseInfo(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doGetGroupInfo(args, parsed_globals):
+def doSearchFaces(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -299,9 +301,9 @@ def doGetGroupInfo(args, parsed_globals):
     client = mod.IaiClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.GetGroupInfoRequest()
+    model = models.SearchFacesRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.GetGroupInfo(model)
+    rsp = client.SearchFaces(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -472,7 +474,7 @@ def doCreatePerson(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doSearchFaces(args, parsed_globals):
+def doGetGroupInfo(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -488,9 +490,9 @@ def doSearchFaces(args, parsed_globals):
     client = mod.IaiClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.SearchFacesRequest()
+    model = models.GetGroupInfoRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.SearchFaces(model)
+    rsp = client.GetGroupInfo(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -580,6 +582,33 @@ def doVerifyPerson(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDetectFaceAttributes(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.IaiClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DetectFaceAttributesRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DetectFaceAttributes(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doModifyPersonGroupInfo(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -763,17 +792,18 @@ ACTION_MAP = {
     "GetPersonGroupInfo": doGetPersonGroupInfo,
     "AnalyzeFace": doAnalyzeFace,
     "ModifyPersonBaseInfo": doModifyPersonBaseInfo,
-    "GetGroupInfo": doGetGroupInfo,
+    "SearchFaces": doSearchFaces,
     "CopyPerson": doCopyPerson,
     "VerifyFace": doVerifyFace,
     "DeleteGroup": doDeleteGroup,
     "DeletePerson": doDeletePerson,
     "ModifyGroup": doModifyGroup,
     "CreatePerson": doCreatePerson,
-    "SearchFaces": doSearchFaces,
+    "GetGroupInfo": doGetGroupInfo,
     "DetectFace": doDetectFace,
     "GetPersonList": doGetPersonList,
     "VerifyPerson": doVerifyPerson,
+    "DetectFaceAttributes": doDetectFaceAttributes,
     "ModifyPersonGroupInfo": doModifyPersonGroupInfo,
     "SearchPersons": doSearchPersons,
     "CompareFace": doCompareFace,
@@ -858,5 +888,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
