@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -94,7 +96,7 @@ def doCreateStreamLiveInput(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeStreamLiveChannelLogs(args, parsed_globals):
+def doDeleteStreamLivePlan(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -110,9 +112,9 @@ def doDescribeStreamLiveChannelLogs(args, parsed_globals):
     client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeStreamLiveChannelLogsRequest()
+    model = models.DeleteStreamLivePlanRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribeStreamLiveChannelLogs(model)
+    rsp = client.DeleteStreamLivePlan(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -229,6 +231,33 @@ def doDescribeStreamLiveRegions(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeStreamLiveTranscodeDetail(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeStreamLiveTranscodeDetailRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeStreamLiveTranscodeDetail(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doCreateStreamLivePlan(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -391,6 +420,60 @@ def doDescribeStreamLivePlans(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doModifyStreamLiveWatermark(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.ModifyStreamLiveWatermarkRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.ModifyStreamLiveWatermark(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doCreateStreamLiveWatermark(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.CreateStreamLiveWatermarkRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.CreateStreamLiveWatermark(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDescribeStreamLiveInputs(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -418,7 +501,7 @@ def doDescribeStreamLiveInputs(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doStartStreamLiveChannel(args, parsed_globals):
+def doDescribeStreamLiveWatermark(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -434,9 +517,36 @@ def doStartStreamLiveChannel(args, parsed_globals):
     client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.StartStreamLiveChannelRequest()
+    model = models.DescribeStreamLiveWatermarkRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.StartStreamLiveChannel(model)
+    rsp = client.DescribeStreamLiveWatermark(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doDescribeStreamLiveChannelLogs(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeStreamLiveChannelLogsRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeStreamLiveChannelLogs(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -472,6 +582,33 @@ def doDescribeStreamLiveInput(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDeleteStreamLiveWatermark(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DeleteStreamLiveWatermarkRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DeleteStreamLiveWatermark(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doModifyStreamLiveInput(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -607,6 +744,33 @@ def doStopStreamLiveChannel(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeStreamLiveWatermarks(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeStreamLiveWatermarksRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeStreamLiveWatermarks(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDeleteStreamLiveInputSecurityGroup(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -661,6 +825,33 @@ def doCreateStreamLiveInputSecurityGroup(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doStartStreamLiveChannel(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MdlClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.StartStreamLiveChannelRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.StartStreamLiveChannel(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 CLIENT_MAP = {
     "v20200326": mdl_client_v20200326,
 
@@ -675,27 +866,34 @@ ACTION_MAP = {
     "DescribeStreamLiveChannelAlerts": doDescribeStreamLiveChannelAlerts,
     "DescribeStreamLiveChannel": doDescribeStreamLiveChannel,
     "CreateStreamLiveInput": doCreateStreamLiveInput,
-    "DescribeStreamLiveChannelLogs": doDescribeStreamLiveChannelLogs,
+    "DeleteStreamLivePlan": doDeleteStreamLivePlan,
     "DescribeStreamLiveInputSecurityGroups": doDescribeStreamLiveInputSecurityGroups,
     "DescribeStreamLiveChannelInputStatistics": doDescribeStreamLiveChannelInputStatistics,
     "DeleteStreamLiveChannel": doDeleteStreamLiveChannel,
     "DescribeStreamLiveRegions": doDescribeStreamLiveRegions,
+    "DescribeStreamLiveTranscodeDetail": doDescribeStreamLiveTranscodeDetail,
     "CreateStreamLivePlan": doCreateStreamLivePlan,
     "CreateStreamLiveChannel": doCreateStreamLiveChannel,
     "ModifyStreamLiveInputSecurityGroup": doModifyStreamLiveInputSecurityGroup,
     "ModifyStreamLiveChannel": doModifyStreamLiveChannel,
     "DescribeStreamLiveChannels": doDescribeStreamLiveChannels,
     "DescribeStreamLivePlans": doDescribeStreamLivePlans,
+    "ModifyStreamLiveWatermark": doModifyStreamLiveWatermark,
+    "CreateStreamLiveWatermark": doCreateStreamLiveWatermark,
     "DescribeStreamLiveInputs": doDescribeStreamLiveInputs,
-    "StartStreamLiveChannel": doStartStreamLiveChannel,
+    "DescribeStreamLiveWatermark": doDescribeStreamLiveWatermark,
+    "DescribeStreamLiveChannelLogs": doDescribeStreamLiveChannelLogs,
     "DescribeStreamLiveInput": doDescribeStreamLiveInput,
+    "DeleteStreamLiveWatermark": doDeleteStreamLiveWatermark,
     "ModifyStreamLiveInput": doModifyStreamLiveInput,
     "DescribeStreamLiveInputSecurityGroup": doDescribeStreamLiveInputSecurityGroup,
     "DeleteStreamLiveInput": doDeleteStreamLiveInput,
     "DescribeStreamLiveChannelOutputStatistics": doDescribeStreamLiveChannelOutputStatistics,
     "StopStreamLiveChannel": doStopStreamLiveChannel,
+    "DescribeStreamLiveWatermarks": doDescribeStreamLiveWatermarks,
     "DeleteStreamLiveInputSecurityGroup": doDeleteStreamLiveInputSecurityGroup,
     "CreateStreamLiveInputSecurityGroup": doCreateStreamLiveInputSecurityGroup,
+    "StartStreamLiveChannel": doStartStreamLiveChannel,
 
 }
 
@@ -774,5 +972,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
