@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -121,6 +123,33 @@ def doSendCustomAlarmMsg(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDescribeConditionsTemplateList(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MonitorClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeConditionsTemplateListRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeConditionsTemplateList(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doDescribeBindingPolicyObjectList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -337,7 +366,7 @@ def doModifyAlarmPolicyCondition(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doModifyAlarmReceivers(args, parsed_globals):
+def doCreateAlarmPolicy(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -353,9 +382,9 @@ def doModifyAlarmReceivers(args, parsed_globals):
     client = mod.MonitorClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ModifyAlarmReceiversRequest()
+    model = models.CreateAlarmPolicyRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.ModifyAlarmReceivers(model)
+    rsp = client.CreateAlarmPolicy(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -607,6 +636,33 @@ def doDescribeAlarmNoticeCallbacks(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doModifyAlarmReceivers(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.MonitorClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.ModifyAlarmReceiversRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.ModifyAlarmReceivers(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doUnBindingAllPolicyObject(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -985,33 +1041,6 @@ def doDeleteAlarmNotices(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doCreateAlarmPolicy(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.MonitorClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.CreateAlarmPolicyRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.CreateAlarmPolicy(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
 def doModifyAlarmNotice(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1108,6 +1137,7 @@ ACTION_MAP = {
     "DescribeAlarmPolicies": doDescribeAlarmPolicies,
     "UnBindingPolicyObject": doUnBindingPolicyObject,
     "SendCustomAlarmMsg": doSendCustomAlarmMsg,
+    "DescribeConditionsTemplateList": doDescribeConditionsTemplateList,
     "DescribeBindingPolicyObjectList": doDescribeBindingPolicyObjectList,
     "ModifyAlarmPolicyNotice": doModifyAlarmPolicyNotice,
     "DescribePolicyGroupList": doDescribePolicyGroupList,
@@ -1116,7 +1146,7 @@ ACTION_MAP = {
     "ModifyAlarmPolicyTasks": doModifyAlarmPolicyTasks,
     "DescribePolicyConditionList": doDescribePolicyConditionList,
     "ModifyAlarmPolicyCondition": doModifyAlarmPolicyCondition,
-    "ModifyAlarmReceivers": doModifyAlarmReceivers,
+    "CreateAlarmPolicy": doCreateAlarmPolicy,
     "BindingPolicyObject": doBindingPolicyObject,
     "CreateAlarmNotice": doCreateAlarmNotice,
     "DescribeBasicAlarmList": doDescribeBasicAlarmList,
@@ -1126,6 +1156,7 @@ ACTION_MAP = {
     "DescribeStatisticData": doDescribeStatisticData,
     "DescribeAlarmNotices": doDescribeAlarmNotices,
     "DescribeAlarmNoticeCallbacks": doDescribeAlarmNoticeCallbacks,
+    "ModifyAlarmReceivers": doModifyAlarmReceivers,
     "UnBindingAllPolicyObject": doUnBindingAllPolicyObject,
     "DeletePolicyGroup": doDeletePolicyGroup,
     "DescribeMonitorTypes": doDescribeMonitorTypes,
@@ -1140,7 +1171,6 @@ ACTION_MAP = {
     "DescribeAlarmNotice": doDescribeAlarmNotice,
     "DescribeAlarmEvents": doDescribeAlarmEvents,
     "DeleteAlarmNotices": doDeleteAlarmNotices,
-    "CreateAlarmPolicy": doCreateAlarmPolicy,
     "ModifyAlarmNotice": doModifyAlarmNotice,
     "SetDefaultAlarmPolicy": doSetDefaultAlarmPolicy,
     "DescribeAlarmPolicy": doDescribeAlarmPolicy,
@@ -1222,5 +1252,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
