@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -13,7 +15,7 @@ from tencentcloud.privatedns.v20201028 import privatedns_client as privatedns_cl
 from tencentcloud.privatedns.v20201028 import models as models_v20201028
 
 
-def doDescribePrivateZone(args, parsed_globals):
+def doCreatePrivateDNSAccount(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -29,9 +31,9 @@ def doDescribePrivateZone(args, parsed_globals):
     client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribePrivateZoneRequest()
+    model = models.CreatePrivateDNSAccountRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribePrivateZone(model)
+    rsp = client.CreatePrivateDNSAccount(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -40,7 +42,7 @@ def doDescribePrivateZone(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribePrivateZoneRecordList(args, parsed_globals):
+def doDescribeAccountVpcList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -56,9 +58,9 @@ def doDescribePrivateZoneRecordList(args, parsed_globals):
     client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribePrivateZoneRecordListRequest()
+    model = models.DescribeAccountVpcListRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribePrivateZoneRecordList(model)
+    rsp = client.DescribeAccountVpcList(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -67,7 +69,7 @@ def doDescribePrivateZoneRecordList(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doModifyPrivateZoneRecord(args, parsed_globals):
+def doModifyPrivateZone(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -83,9 +85,63 @@ def doModifyPrivateZoneRecord(args, parsed_globals):
     client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ModifyPrivateZoneRecordRequest()
+    model = models.ModifyPrivateZoneRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.ModifyPrivateZoneRecord(model)
+    rsp = client.ModifyPrivateZone(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doDescribePrivateZoneService(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribePrivateZoneServiceRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribePrivateZoneService(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doDescribeQuotaUsage(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeQuotaUsageRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeQuotaUsage(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -175,33 +231,6 @@ def doCreatePrivateZone(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribePrivateZoneList(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribePrivateZoneListRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.DescribePrivateZoneList(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
 def doSubscribePrivateZoneService(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -310,60 +339,6 @@ def doDescribeRequestData(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDeletePrivateZoneRecord(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DeletePrivateZoneRecordRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.DeletePrivateZoneRecord(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
-def doModifyPrivateZone(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ModifyPrivateZoneRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.ModifyPrivateZone(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
 def doDescribePrivateDNSAccountList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -391,7 +366,7 @@ def doDescribePrivateDNSAccountList(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDeletePrivateZone(args, parsed_globals):
+def doModifyPrivateZoneRecord(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -407,36 +382,9 @@ def doDeletePrivateZone(args, parsed_globals):
     client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DeletePrivateZoneRequest()
+    model = models.ModifyPrivateZoneRecordRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DeletePrivateZone(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
-def doDescribePrivateZoneService(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.PrivatednsClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribePrivateZoneServiceRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.DescribePrivateZoneService(model)
+    rsp = client.ModifyPrivateZoneRecord(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -456,22 +404,20 @@ MODELS_MAP = {
 }
 
 ACTION_MAP = {
-    "DescribePrivateZone": doDescribePrivateZone,
-    "DescribePrivateZoneRecordList": doDescribePrivateZoneRecordList,
-    "ModifyPrivateZoneRecord": doModifyPrivateZoneRecord,
+    "CreatePrivateDNSAccount": doCreatePrivateDNSAccount,
+    "DescribeAccountVpcList": doDescribeAccountVpcList,
+    "ModifyPrivateZone": doModifyPrivateZone,
+    "DescribePrivateZoneService": doDescribePrivateZoneService,
+    "DescribeQuotaUsage": doDescribeQuotaUsage,
     "DescribeAuditLog": doDescribeAuditLog,
     "CreatePrivateZoneRecord": doCreatePrivateZoneRecord,
     "CreatePrivateZone": doCreatePrivateZone,
-    "DescribePrivateZoneList": doDescribePrivateZoneList,
     "SubscribePrivateZoneService": doSubscribePrivateZoneService,
     "DescribeDashboard": doDescribeDashboard,
     "ModifyPrivateZoneVpc": doModifyPrivateZoneVpc,
     "DescribeRequestData": doDescribeRequestData,
-    "DeletePrivateZoneRecord": doDeletePrivateZoneRecord,
-    "ModifyPrivateZone": doModifyPrivateZone,
     "DescribePrivateDNSAccountList": doDescribePrivateDNSAccountList,
-    "DeletePrivateZone": doDeletePrivateZone,
-    "DescribePrivateZoneService": doDescribePrivateZoneService,
+    "ModifyPrivateZoneRecord": doModifyPrivateZoneRecord,
 
 }
 
@@ -550,5 +496,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
