@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
+import six
 import json
 import tccli.options_define as OptionsDefine
 import tccli.format_output as FormatOutput
 from tccli import __version__
 from tccli.utils import Utils
-from tccli.exceptions import ConfigurationError
+from tccli.exceptions import ConfigurationError, ParamError
 from tencentcloud.common import credential
 from tencentcloud.common.profile.http_profile import HttpProfile
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -67,33 +69,6 @@ def doDeleteMultipleSecurityPolicy(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doManageReplication(args, parsed_globals):
-    g_param = parse_global_arg(parsed_globals)
-
-    cred = credential.Credential(
-        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
-    )
-    http_profile = HttpProfile(
-        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
-        reqMethod="POST",
-        endpoint=g_param[OptionsDefine.Endpoint]
-    )
-    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
-    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
-    client = mod.TcrClient(cred, g_param[OptionsDefine.Region], profile)
-    client._sdkVersion += ("_CLI_" + __version__)
-    models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ManageReplicationRequest()
-    model.from_json_string(json.dumps(args))
-    rsp = client.ManageReplication(model)
-    result = rsp.to_json_string()
-    try:
-        json_obj = json.loads(result)
-    except TypeError as e:
-        json_obj = json.loads(result.decode('utf-8'))  # python3.3
-    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
-
-
 def doCheckInstance(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -121,7 +96,7 @@ def doCheckInstance(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeImmutableTagRules(args, parsed_globals):
+def doManageReplication(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -137,9 +112,36 @@ def doDescribeImmutableTagRules(args, parsed_globals):
     client = mod.TcrClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeImmutableTagRulesRequest()
+    model = models.ManageReplicationRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.DescribeImmutableTagRules(model)
+    rsp = client.ManageReplication(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doCreateMultipleSecurityPolicy(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.TcrClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.CreateMultipleSecurityPolicyRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.CreateMultipleSecurityPolicy(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -283,7 +285,7 @@ def doDeleteImmutableTagRules(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doCreateMultipleSecurityPolicy(args, parsed_globals):
+def doCreateInstanceToken(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     cred = credential.Credential(
@@ -299,9 +301,36 @@ def doCreateMultipleSecurityPolicy(args, parsed_globals):
     client = mod.TcrClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.CreateMultipleSecurityPolicyRequest()
+    model = models.CreateInstanceTokenRequest()
     model.from_json_string(json.dumps(args))
-    rsp = client.CreateMultipleSecurityPolicy(model)
+    rsp = client.CreateInstanceToken(model)
+    result = rsp.to_json_string()
+    try:
+        json_obj = json.loads(result)
+    except TypeError as e:
+        json_obj = json.loads(result.decode('utf-8'))  # python3.3
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
+def doDescribeImmutableTagRules(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    cred = credential.Credential(
+        g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+    )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.TcrClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DescribeImmutableTagRulesRequest()
+    model.from_json_string(json.dumps(args))
+    rsp = client.DescribeImmutableTagRules(model)
     result = rsp.to_json_string()
     try:
         json_obj = json.loads(result)
@@ -377,15 +406,16 @@ MODELS_MAP = {
 ACTION_MAP = {
     "CreateReplicationInstance": doCreateReplicationInstance,
     "DeleteMultipleSecurityPolicy": doDeleteMultipleSecurityPolicy,
-    "ManageReplication": doManageReplication,
     "CheckInstance": doCheckInstance,
-    "DescribeImmutableTagRules": doDescribeImmutableTagRules,
+    "ManageReplication": doManageReplication,
+    "CreateMultipleSecurityPolicy": doCreateMultipleSecurityPolicy,
     "CreateImmutableTagRules": doCreateImmutableTagRules,
     "DescribeReplicationInstanceSyncStatus": doDescribeReplicationInstanceSyncStatus,
     "DescribeReplicationInstanceCreateTasks": doDescribeReplicationInstanceCreateTasks,
     "ModifyImmutableTagRules": doModifyImmutableTagRules,
     "DeleteImmutableTagRules": doDeleteImmutableTagRules,
-    "CreateMultipleSecurityPolicy": doCreateMultipleSecurityPolicy,
+    "CreateInstanceToken": doCreateInstanceToken,
+    "DescribeImmutableTagRules": doDescribeImmutableTagRules,
     "ModifyInstance": doModifyInstance,
     "DescribeReplicationInstances": doDescribeReplicationInstances,
 
@@ -466,5 +496,9 @@ def parse_global_arg(parsed_globals):
     if g_param[OptionsDefine.Version] not in AVAILABLE_VERSION_LIST:
         raise Exception("available versions: %s" % " ".join(AVAILABLE_VERSION_LIST))
 
+    if six.PY2:
+        for key, value in g_param.items():
+            if isinstance(value, six.text_type):
+                g_param[key] = value.encode('utf-8')
     return g_param
 
